pub unsafe extern "C" fn darts_clear(darts: DartsT)Expand description
Frees memory allocated to units and then initializes member
variables with 0 and NULLs. Note that this does not free memory if
the array of units was set by darts_set_array.
pub unsafe extern "C" fn darts_clear(darts: DartsT)Frees memory allocated to units and then initializes member
variables with 0 and NULLs. Note that this does not free memory if
the array of units was set by darts_set_array.