pub unsafe extern "C" fn darts_save(
darts: DartsT,
file_name: *const c_char,
mode: *const c_char,
offset: size_t,
) -> c_intExpand description
Writes the array of units into the specified file. `offset’ specifies the number of bytes to be skipped before writing the array. Returns 0 iff the operation succeeds. Otherwise, returns a non-zero value.